/*
 * Copyright (c) 2016, 2021, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */

package java.awt.desktop;

import java.awt.Desktop;
import java.awt.GraphicsEnvironment;
import java.awt.HeadlessException;
import java.io.Serial;
import java.util.EventObject;

/**
 * AppEvents are sent to listeners and handlers installed on the
 * {@link java.awt.Desktop} instance of the current desktop context.
 *
 * @since 9
 * @sealedGraph
 */
public sealed class AppEvent extends EventObject
    permits AboutEvent,
            AppForegroundEvent,
            AppHiddenEvent,
            AppReopenedEvent,
            FilesEvent,
            OpenURIEvent,
            PreferencesEvent,
            QuitEvent,
            ScreenSleepEvent,
            SystemSleepEvent,
            UserSessionEvent {

    /**
     * Use serialVersionUID from JDK 9 for interoperability.
     */
    @Serial
    private static final long serialVersionUID = -5958503993556009432L;

    /**
     * Constructs an {@code AppEvent}.
     *
     * @throws HeadlessException if {@link GraphicsEnvironment#isHeadless()}
     *         returns {@code true}
     * @throws UnsupportedOperationException if Desktop API is not supported on
     *         the current platform
     * @see Desktop#isDesktopSupported()
     * @see java.awt.GraphicsEnvironment#isHeadless
     */
    AppEvent() {
        super(Desktop.getDesktop());
    }
}
